'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.actionCreator = undefined;

var _constants = require('../utils/constants');

var _config = require('../utils/config');

var _config2 = _interopRequireDefault(_config);

var _fs = require('../utils/fs');

var _helpers = require('../utils/helpers');

var _api = require('../utils/api');

var _api2 = _interopRequireDefault(_api);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /*
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * LiskHQ/lisky
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Copyright © 2017 Lisk Foundation
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * See the LICENSE file at the top-level directory of this distribution
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * for licensing information.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * no part of this software, including this file, may be copied, modified,
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * propagated, or distributed except according to the terms contained in the
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * LICENSE file.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Removal or modification of this copyright notice is prohibited.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */


var description = 'Sets configuration <variable> to <value>. Variables available: json, name, testnet. Configuration is persisted in `' + _config.configFilePath + '`.\n\n\tExamples:\n\t- set json true\n\t- set name my_custom_lisky\n';

var WRITE_FAIL_WARNING = 'Config file could not be written: your changes will not be persisted.';

var writeConfigToFile = function writeConfigToFile(newConfig) {
	try {
		(0, _fs.writeJsonSync)(_config.configFilePath, newConfig);
		return true;
	} catch (e) {
		return false;
	}
};

var checkBoolean = function checkBoolean(value) {
	return ['true', 'false'].includes(value);
};

var setNestedConfigProperty = function setNestedConfigProperty(newValue) {
	return function (obj, pathComponent, i, path) {
		if (i === path.length - 1) {
			// eslint-disable-next-line no-param-reassign
			obj[pathComponent] = newValue;
			return _config2.default;
		}
		return obj[pathComponent];
	};
};

var attemptWriteToFile = function attemptWriteToFile(variable, value) {
	var writeSuccess = writeConfigToFile(_config2.default);

	if (!writeSuccess && process.env.NON_INTERACTIVE_MODE === 'true') {
		throw new Error(WRITE_FAIL_WARNING);
	}

	var result = {
		message: 'Successfully set ' + variable + ' to ' + value + '.'
	};

	if (!writeSuccess) {
		result.warning = WRITE_FAIL_WARNING;
	}

	return result;
};

var setBoolean = function setBoolean(variable, path) {
	return function (value) {
		if (!checkBoolean(value)) {
			throw new Error('Value must be a boolean.');
		}

		var newValue = value === 'true';
		path.reduce(setNestedConfigProperty(newValue), _config2.default);

		if (variable === 'testnet') {
			_api2.default.setTestnet(newValue);
		}

		return attemptWriteToFile(variable, value);
	};
};

var setString = function setString(variable, path) {
	return function (value) {
		path.reduce(setNestedConfigProperty(value), _config2.default);
		return attemptWriteToFile(variable, value);
	};
};

var handlers = {
	json: setBoolean('json', ['json']),
	name: setString('name', ['name']),
	pretty: setBoolean('pretty', ['pretty']),
	testnet: setBoolean('testnet', ['liskJS', 'testnet'])
};

var actionCreator = exports.actionCreator = function actionCreator() {
	return function () {
		var _ref2 = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(_ref) {
			var variable = _ref.variable,
			    value = _ref.value;
			return regeneratorRuntime.wrap(function _callee$(_context) {
				while (1) {
					switch (_context.prev = _context.next) {
						case 0:
							if (_constants.CONFIG_VARIABLES.includes(variable)) {
								_context.next = 2;
								break;
							}

							throw new Error('Unsupported variable name.');

						case 2:
							return _context.abrupt('return', handlers[variable](value));

						case 3:
						case 'end':
							return _context.stop();
					}
				}
			}, _callee, undefined);
		}));

		return function (_x) {
			return _ref2.apply(this, arguments);
		};
	}();
};

var set = (0, _helpers.createCommand)({
	command: 'set <variable> <value>',
	autocomplete: _constants.CONFIG_VARIABLES,
	description: description,
	actionCreator: actionCreator,
	errorPrefix: 'Could not set config variable'
});

exports.default = set;