'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.configFilePath = undefined;

var _os = require('os');

var _os2 = _interopRequireDefault(_os);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _lockfile = require('lockfile');

var _lockfile2 = _interopRequireDefault(_lockfile);

var _defaultConfig = require('../../defaultConfig.json');

var _defaultConfig2 = _interopRequireDefault(_defaultConfig);

var _fs3 = require('./fs');

var _print = require('./print');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisky
 * Copyright © 2017 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
var configDirName = '.lisky';
var configFileName = 'config.json';
var lockfileName = 'config.lock';
var homedir = _os2.default.homedir();
var configDirPath = process.env.LISKY_CONFIG_DIR || homedir + '/' + configDirName;
var configFilePath = exports.configFilePath = configDirPath + '/' + configFileName;
var lockfilePath = configDirPath + '/' + lockfileName;

var attemptCallWithWarning = function attemptCallWithWarning(fn, path) {
	try {
		return fn();
	} catch (_) {
		var warning = 'WARNING: Could not write to `' + path + '`. Your configuration will not be persisted.';
		return (0, _print.logWarning)(warning);
	}
};

var attemptCallWithError = function attemptCallWithError(fn, errorCode, errorMessage) {
	try {
		return fn();
	} catch (_) {
		(0, _print.logError)(errorMessage);
		return process.exit(errorCode);
	}
};

var attemptToCreateDir = function attemptToCreateDir(path) {
	var fn = _fs2.default.mkdirSync.bind(null, path);
	return attemptCallWithWarning(fn, path);
};

var attemptToCreateFile = function attemptToCreateFile(path) {
	var fn = _fs3.writeJsonSync.bind(null, path, _defaultConfig2.default);
	return attemptCallWithWarning(fn, path);
};

var checkReadAccess = function checkReadAccess(path) {
	var fn = _fs2.default.accessSync.bind(null, path, _fs2.default.constants.R_OK);
	var errorCode = 1;
	var errorMessage = 'Could not read config file. Please check permissions for ' + path + ' or delete the file so we can create a new one from defaults.';
	return attemptCallWithError(fn, errorCode, errorMessage);
};

var checkLockfile = function checkLockfile(path) {
	var fn = _lockfile2.default.lockSync.bind(null, path);
	var errorCode = 3;
	var errorMessage = 'Config lockfile at ' + lockfilePath + ' found. Are you running Lisky in another process?';
	return attemptCallWithError(fn, errorCode, errorMessage);
};

var attemptToReadJsonFile = function attemptToReadJsonFile(path) {
	var fn = _fs3.readJsonSync.bind(null, path);
	var errorCode = 2;
	var errorMessage = 'Config file is not valid JSON. Please check ' + path + ' or delete the file so we can create a new one from defaults.';
	return attemptCallWithError(fn, errorCode, errorMessage);
};

var getConfig = function getConfig() {
	if (!_fs2.default.existsSync(configDirPath)) {
		attemptToCreateDir(configDirPath);
	}

	if (!_fs2.default.existsSync(configFilePath)) {
		attemptToCreateFile(configFilePath);
		return _defaultConfig2.default;
	}

	if (!process.env.EXEC_FILE_CHILD) {
		checkLockfile(lockfilePath);
	}

	checkReadAccess(configFilePath);

	return attemptToReadJsonFile(configFilePath);
};

exports.default = getConfig();