'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.createCommand = exports.wrapActionCreator = exports.createErrorHandler = exports.shouldUsePrettyOutput = exports.shouldUseJsonOutput = exports.processQueryResult = exports.deAlias = exports.validateAmount = exports.validateAddress = exports.validateMinimum = exports.validateLifetime = exports.prependMinusToPublicKeys = exports.prependPlusToPublicKeys = exports.validatePublicKeys = undefined;

var _error = require('../utils/error');

var _options = require('../utils/options');

var _options2 = _interopRequireDefault(_options);

var _print = require('../utils/print');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } } /*
                                                                                                                                                                                                     * LiskHQ/lisky
                                                                                                                                                                                                     * Copyright © 2017 Lisk Foundation
                                                                                                                                                                                                     *
                                                                                                                                                                                                     * See the LICENSE file at the top-level directory of this distribution
                                                                                                                                                                                                     * for licensing information.
                                                                                                                                                                                                     *
                                                                                                                                                                                                     * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                                                                                                                                                                                     * no part of this software, including this file, may be copied, modified,
                                                                                                                                                                                                     * propagated, or distributed except according to the terms contained in the
                                                                                                                                                                                                     * LICENSE file.
                                                                                                                                                                                                     *
                                                                                                                                                                                                     * Removal or modification of this copyright notice is prohibited.
                                                                                                                                                                                                     *
                                                                                                                                                                                                     */


var validatePublicKeys = exports.validatePublicKeys = function validatePublicKeys(publicKeys) {
	return publicKeys.map(function (publicKey) {
		try {
			Buffer.from(publicKey, 'hex');
		} catch (error) {
			throw new _error.ValidationError('Error processing public key ' + publicKey + ': ' + error.message + '.');
		}
		if (publicKey.length !== 64) {
			throw new _error.ValidationError('Public key ' + publicKey + ' length differs from the expected 64 hex characters for a public key.');
		}

		if (Buffer.from(publicKey, 'hex').length !== 32) {
			throw new _error.ValidationError('Public key ' + publicKey + ' bytes length differs from the expected 32 bytes for a public key.');
		}
		return publicKey;
	});
};

var prependPlusToPublicKeys = exports.prependPlusToPublicKeys = function prependPlusToPublicKeys(publicKeys) {
	return publicKeys.map(function (publicKey) {
		return '+' + publicKey;
	});
};

var prependMinusToPublicKeys = exports.prependMinusToPublicKeys = function prependMinusToPublicKeys(publicKeys) {
	return publicKeys.map(function (publicKey) {
		return '-' + publicKey;
	});
};

var regExpAddress = /^\d{1,21}[L|l]$/;
var regExpAmount = /^\d+(\.\d{1,8})?$/;

var isStringInteger = function isStringInteger(n) {
	var parsed = parseInt(n, 10);
	return !Number.isNaN(parsed) && parsed.toString() === n;
};

var validateLifetime = exports.validateLifetime = function validateLifetime(lifetime) {
	if (!isStringInteger(lifetime)) {
		throw new _error.ValidationError('Lifetime must be an integer.');
	}
	return true;
};

var validateMinimum = exports.validateMinimum = function validateMinimum(minimum) {
	if (!isStringInteger(minimum)) {
		throw new _error.ValidationError('Minimum number of signatures must be an integer.');
	}
	return true;
};

var validateAddress = exports.validateAddress = function validateAddress(address) {
	if (!address.match(regExpAddress)) {
		throw new _error.ValidationError(address + ' is not a valid address.');
	}
	return true;
};

var validateAmount = exports.validateAmount = function validateAmount(amount) {
	if (!amount.match(regExpAmount)) {
		throw new _error.ValidationError('Amount must be a number with no more than 8 decimal places.');
	}
	return true;
};

var deAlias = exports.deAlias = function deAlias(type) {
	return type === 'address' ? 'account' : type;
};

var processQueryResult = exports.processQueryResult = function processQueryResult(type) {
	return function (result) {
		return result.error ? result : result[deAlias(type)];
	};
};

var shouldUseJsonOutput = exports.shouldUseJsonOutput = function shouldUseJsonOutput(config, options) {
	return (options.json === true || config.json === true) && options.json !== false;
};

var shouldUsePrettyOutput = exports.shouldUsePrettyOutput = function shouldUsePrettyOutput(config, options) {
	return (options.pretty === true || config.pretty === true) && options.pretty !== false;
};

var createErrorHandler = exports.createErrorHandler = function createErrorHandler(prefix) {
	return function (_ref) {
		var message = _ref.message;
		return {
			error: prefix + ': ' + message
		};
	};
};

var wrapActionCreator = exports.wrapActionCreator = function wrapActionCreator(vorpal, actionCreator, errorPrefix) {
	return function (parameters) {
		return actionCreator(vorpal)(parameters).catch(createErrorHandler(errorPrefix)).then((0, _print.printResult)(vorpal, parameters.options));
	};
};

var OPTION_TYPES = {
	string: ['message', 'passphrase', 'password', 'second-passphrase', 'unvotes', 'votes']
};

var createCommand = exports.createCommand = function createCommand(_ref2) {
	var command = _ref2.command,
	    autocomplete = _ref2.autocomplete,
	    description = _ref2.description,
	    alias = _ref2.alias,
	    actionCreator = _ref2.actionCreator,
	    _ref2$options = _ref2.options,
	    options = _ref2$options === undefined ? [] : _ref2$options,
	    errorPrefix = _ref2.errorPrefix;
	return function createdCommand(vorpal) {
		var action = wrapActionCreator(vorpal, actionCreator, errorPrefix);
		var commandInstance = vorpal.command(command).autocomplete(autocomplete).description(description).types(OPTION_TYPES).action(action);

		if (alias) commandInstance.alias(alias);

		[_options2.default.json, _options2.default.noJson, _options2.default.pretty].concat(_toConsumableArray(options)).forEach(function (option) {
			return commandInstance.option.apply(commandInstance, _toConsumableArray(option));
		});
	};
};